Struct EccHandle
Source pub struct EccHandle<'t>();
A handle for an in-progress operation.
Polls the status of the work item.
Returns whether the item has been processed.
Polls the work item to completion, by busy-looping.
Returns immediately if poll returns true.
Waits until the work item is completed.
Cancels the work item and asynchronously waits until it is removed from the work queue.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.